# Py MadVR

Support for IP based controls for Envys''

*Note: IP control does not work if there is no input signal, by design"

Readme WIP

## Commands
same as the one in the docs like PowerOff. 

For things that take params, use a command -> KeyPress, MENU

if you want to use power_off() you need to run it before turnging off other stuff bc render thread
Recomend configuring update to be short, less than 5 seconds